soc/intel/common/crashlog: Fix checking PMC record size

Check pmc_record_size variable for collecting PMC records,
instead of cpu_record_size variable.

Bug=None
TEST=Able to build. With Meteor Lake SOC related patch, able to
capture and decode crashlog.

Change-Id: I4c35ba2bcf757231aa2872802eb82d4d50742cd9
Signed-off-by: Pratikkumar Prajapati <pratikkumar.v.prajapati@intel.com>
Reviewed-on: https://review.coreboot.org/c/coreboot/+/75526
Reviewed-by: Subrata Banik <subratabanik@google.com>
Tested-by: build bot (Jenkins) <no-reply@coreboot.org>
diff --git a/src/soc/intel/common/block/acpi/acpi_bert.c b/src/soc/intel/common/block/acpi/acpi_bert.c
index 7743ccc..16df60a 100644
--- a/src/soc/intel/common/block/acpi/acpi_bert.c
+++ b/src/soc/intel/common/block/acpi/acpi_bert.c
@@ -68,8 +68,8 @@
 
 	pmc_record_size = cl_get_pmc_record_size();
 	if (pmc_record_size) {
-		/*  Allocate new FW ERR structure in case CPU crashlog is present */
-		if (cpu_record_size && !bert_append_fw_err(status)) {
+		/* Allocate new FW ERR structure in case PMC crashlog is present */
+		if (pmc_record_size && !bert_append_fw_err(status)) {
 			printk(BIOS_ERR, "Crashlog PMC entry would "
 				"exceed available region\n");
 			return CB_ERR;